@@ -9,12 +9,12 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.Transfer 1.21.23\nVersion:         1.21.23\nBuilder version:"
-        " 7.4.0\nDocs:           "
-        " https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer//\nBoto3 docs:     "
+        "Type annotations for boto3.Transfer 1.22.8\nVersion:         1.22.8\nBuilder version:"
+        " 7.5.12\nDocs:           "
+        " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
-        " https://github.com/vemel/mypy_boto3_builder/releases"
+        " https://github.com/youtype/mypy_boto3_builder/releases"
     )
 
 
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.21.23")
+    print("1.22.8")
 
 
 def main() -> None:
